You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tamaya.apache.org by pl...@apache.org on 2014/12/08 09:00:26 UTC

incubator-tamaya git commit: Improved signature of AggregationPolicy#aggregate(...)

Repository: incubator-tamaya
Updated Branches:
  refs/heads/master 1a3e51206 -> f46e2f194


Improved signature of AggregationPolicy#aggregate(...)


Project: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/commit/f46e2f19
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/tree/f46e2f19
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/diff/f46e2f19

Branch: refs/heads/master
Commit: f46e2f1943250b5d86cb6915c4b264ca5e29e6c2
Parents: 1a3e512
Author: Oliver B. Fischer <pl...@apache.org>
Authored: Mon Dec 8 08:59:32 2014 +0100
Committer: Oliver B. Fischer <pl...@apache.org>
Committed: Mon Dec 8 09:00:18 2014 +0100

----------------------------------------------------------------------
 api/src/main/java/org/apache/tamaya/AggregationPolicy.java | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/f46e2f19/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/AggregationPolicy.java b/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
index 886e193..f7eb420 100644
--- a/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
+++ b/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
@@ -25,12 +25,12 @@ public interface AggregationPolicy {
 
     /**
      * Method which decides how keys/values are aggregated.
      * @param key the key current the entry
      * @param value1 the current value, or null.
      * @param value2 the new value, never null.
      * @return the target value to be used in the resulting property set, or null, to remove the property.
      */
-    public String aggregate(String key, String value1, String value2);
+    public String aggregate(String key, String currentValue, String newValue);
 
     /** Ignore overrides, only extend (additive). */
     public static final AggregationPolicy IGNORE_DUPLICATES = (k, v1, v2) -> v1 == null? v2 : v1;
@@ -25,12 +25,12 @@ public interface AggregationPolicy {
     /**
      * Method which decides how keys/values are aggregated.
-     * @param key the key current the entry
-     * @param value1 the current value, or null.
-     * @param value2 the new value, never null.
+     * @param key the key current the entry, must not be {@code null}.
+     * @param currentValue the current value, or {@code null}.
+     * @param newValue the new value, never {@code null}.
      * @return the target value to be used in the resulting property set, or null, to remove the property.
      */